@@ -11,8 +11,13 @@ class UserPagesViews(object):
 
     def __call__(self, request: HttpRequest):
         logger.debug(f"{__name__} call")
-        if request.user.is_authenticated and request.method == HttpRequest.GET:
-            # to be completed
-            pass
+
+        if request.user.is_authenticated and \
+                request.method == HttpRequest.GET and \
+                hasattr(request.user, "page_views_counter"):
+            setattr(request.user,
+                    "page_views_counter",
+                    getattr(request.user, "page_views_counter") + 1)
+            request.user.save()
         response = self.get_response(request)
         return response
